@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.01_002";
+our $VERSION = "0.02_001";
 use Moo;
 use JSON::Tiny qw[decode_json];
 use strictures 2;
@@ -15,8 +15,12 @@ has $_ => (is => 'ro', required => 1, writer => "_set_$_")
      cash_held_for_orders deactivated deposit_halted margin_balances
      max_ach_early_access_amount only_position_closing_trades sma
      sma_held_for_orders sweep_enabled type uncleared_deposits unsettled_funds
-     updated_at withdrawal_halted url]
+     withdrawal_halted url]
     );
+has $_ => (is       => 'ro',
+           required => 1,
+           coerce   => \&Finance::Robinhood::_2_datetime
+) for (qw[updated_at]);
 has $_ => (is => 'bare', required => 1, accessor => "_get_$_", weak_ref => 1)
     for (qw[rh]);
 
@@ -34,7 +38,7 @@ sub positions {
             return '?nonzero=' . ($opt->{nonzero} ? 'true' : 'false')
                 if defined $opt->{nonzero};
             return '';
-        }
+            }
             ->($type)
     );
     return
@@ -56,7 +60,7 @@ sub portfolio {
 
 =head1 NAME
 
-Finance::Robinhood::Account - Single securities trade account
+Finance::Robinhood::Account - Single Robinhood Trade Acount
 
 =head1 SYNOPSIS
 
